GeneralPurpose

Struct GeneralPurpose 

pub struct GeneralPurpose {
    encode_table: [u8; 64],
    decode_table: [u8; 256],
    pub(crate) padding: Symbol,
    config: GeneralPurposeConfig,
}
A general-purpose base64 engine.

  • It uses no vector CPU instructions, so it will work on any system. For a version that uses SIMD where available, see the SIMD engines behind the simd-unsafe feature.
  • It is reasonably fast (~2-3GiB/s).
  • It is not constant-time, though, so it is vulnerable to timing side-channel attacks. For loading cryptographic keys, etc, it is suggested to use the forthcoming constant-time implementation.

Fields

encode_table: [u8; 64]decode_table: [u8; 256]padding: Symbolconfig: GeneralPurposeConfig

Implementations

Source

impl GeneralPurpose

pub const fn new(alphabet: &Alphabet, config: GeneralPurposeConfig) -> Self

Create a GeneralPurpose engine from an Alphabet.

While not very expensive to initialize, ideally these should be cached if the engine will be used repeatedly.

pub(crate) fn encode_table(&self) -> &[u8; 64]

The 6-bit-index-to-ASCII encode table.

pub(crate) fn decode_table(&self) -> &[u8; 256]

The ASCII-to-6-bit-value decode table.